$Data = Import-csv -Path c:\temp\FirstAD.csv

$ComputerName = $Data.ComputerName
$Password = $Data.NewDSRMAdminPassword
$DomainName = $Data.DomainName
$MOFfiles = $Data.MOFFileLocation
$Cred = ConvertTo-SecureString -String $Password -Force -AsPlainText
$DomainCredential = New-Object System.Management.Automation.PSCredential ("$(($DomainName -split '\.')[0])\Administrator", $Cred)
$DSRMpassword = New-Object System.Management.Automation.PSCredential ('No UserName', $Cred)
$RemoteAdministratorCred = Get-Credential -UserName Administrator -Message "$ComputerName Administrator password"
$CimSession = New-CimSession -ComputerName $ComputerName -Credential $RemoteAdministratorCred -Name $ComputerName

Configuration NewActiveDirectoryConfig {
    param (
        [Parameter(Mandatory)] 
        [PSCredential]$DomainCredential,
        [Parameter(Mandatory)] 
        [PSCredential]$DSRMpassword
    )

    Import-DscResource ModuleName xActiveDirectory
    
    Node $ComputerName {
        WindowsFeature ActiveDirectory {
            Ensure = 'Present'
            Name = 'AD-Domain-Services'
        }
        WindowsFeature ActiveDirectoryTools {
            Ensure = 'Present'
            Name = 'RSAT-AD-Tools'
            DependsOn = "[WindowsFeature]ActiveDirectory"
        }
        WindowsFeature DNSServerTools {
            Ensure = 'Present'
            Name = 'RSAT-DNS-Server'
            DependsOn = "[WindowsFeature]ActiveDirectoryTools"
        }
        WindowsFeature ActiveDirectoryPowershell {
            Ensure = "Present"
            Name   = "RSAT-AD-PowerShell"
            DependsOn = "[WindowsFeature]DNSServerTools"
        }

        xADDomain RootDomain {
            Domainname = $DomainName
            SafemodeAdministratorPassword  = $DSRMpassword
            DomainAdministratorCredential = $DomainCredential
            #DomainNetbiosName = ($DomainName -split '\.')[0]
            DependsOn = "[WindowsFeature]ActiveDirectory", "[WindowsFeature]ActiveDirectoryPowershell"
        }

        LocalConfigurationManager {            
            ActionAfterReboot = 'ContinueConfiguration'            
            ConfigurationMode = 'ApplyOnly'            
            RebootNodeIfNeeded = $true            
        }            

        <#
        Script RestartServer {
            GetScript = {
                # Do Nothing
            }
            SetScript = {
                Restart-Computer -Force 
            }
            TestScript = {
                $false
            }

            DependsOn = "[xADDomain]RootDomain"
        }
        #>
    }
}

$ConfigurationData = @{
    AllNodes = @(
        @{
            NodeName = $ComputerName
            PSDscAllowPlainTextPassword = $true
            DomainName = $DomainName
         }
    )
}
    
NewActiveDirectoryConfig -DSRMpassword $DSRMpassword -DomainCredential $DomainCredential -OutputPath $MOFfiles -ConfigurationData $ConfigurationData

Set-DSCLocalConfigurationManager -Path $MOFfiles Verbose -CimSession $CimSession

Start-DscConfiguration -Path $MOFfiles -Verbose -CimSession $CimSession -Wait -Force
